@@ -1,4 +1,5 @@
 import re
+from src.util import merge_params
 import subprocess
 
 from termcolor import colored
@@ -10,13 +11,27 @@ from pathlib import Path
 pathDataRe = re.compile(r"path\.data\s?=", re.IGNORECASE)
 
 
-@click.command(help="Runs elastic search from the current kibana clone. It will use parameters from the ~/.kibbe [elastic.params] section.")
+@click.command(context_settings=dict(
+    ignore_unknown_options=True,
+))
 @click.option('--data-dir', '-d', type=click.STRING, default="esdata", help="Path where this elastic search will store its data (path.data)")
 @click.option('--no-persist', '-n', default=False, is_flag=True, help="If passed will use a disposable data dir. This option will overwrite other options related to data dir.")
 @click.option('-E', multiple=True, help="Additional options to pass to elastic search. `path.data` will be ignored")
-def es(data_dir, no_persist, e):
+@click.argument('unparsed_args', nargs=-1, type=click.UNPROCESSED)
+def es(data_dir, no_persist, e, unparsed_args):
+    """
+        Runs elastic search from the current kibana clone.
 
-    params = process_params(data_dir, no_persist)
+        You can also pass the same parameters as you'd pass to `node scritps/es`
+
+        You can persist the -E parameters by using a configuration file `~/.kibbe`.
+        with the [elastic.params] section.
+
+        See more about the configuration file here:
+        https://github.com/academo/kibbe#configuration-file
+    """
+
+    e_params = process_params(data_dir, no_persist)
 
     # additional -E params
     for item in e:
@@ -24,20 +39,24 @@ def es(data_dir, no_persist, e):
         # ignore path.data
         if pathDataRe.match(item):
             continue
-        params.append(item)
+        e_params.append(item)
 
-    command = get_command(params)
+    config = get_config()
+    config_params = config.items('elastic.params', raw=True)
+    params = merge_params(config_params, unparsed_args)
+
+    command = get_command(e_params, extra_params=params)
     click.echo("Will run elastic search as: " + colored(' '.join(command), 'yellow'))
-    subprocess.run(command)
+    # subprocess.run(command)
 
 
-def get_command(params):
+def get_command(e_params, extra_params):
     final_params = []
-    for param in params:
+    for param in e_params:
         final_params.append('-E')
         final_params.append(param)
 
-    return ['node', 'scripts/es', 'snapshot'] + final_params
+    return ['node', 'scripts/es', 'snapshot'] + final_params + extra_params
 
 
 def process_params(data_dir, no_persist):
